| Title: | JWST Color Palette for R |
|---|---|
| Description: | An R color palette inspired by the images from the JWST. |
| Authors: | Eric Leung [aut, cre] (ORCID: <https://orcid.org/0000-0002-8724-1872>) |
| Maintainer: | Eric Leung <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 05:16:07 UTC |
| Source: | https://github.com/erictleung/jwst |
Function derived from https://github.com/ciannabp/inauguration with minor changes.
jwst(name, n)jwst(name, n)
name |
Name of desired palette. Choices are:
|
n |
Number of colors desired. All palettes have 9 colors. Most color schemes are derived from If omitted, uses all colors. |
A vector of colors.
jwst("carina")jwst("carina")
Use jwst to construct palettes of desired length.
jwst_palettesjwst_palettes
An object of class list of length 5.